==> flowcean-0.1.0.tar.gz: flowcean-0.1.0/src/flowcean/environments/uri.py <==
from pathlib import Path
from typing import Self, override
from urllib.parse import urlparse

import polars as pl

from flowcean.core import OfflineEnvironment
from flowcean.core.environment import NotLoadedError
from flowcean.environments.csv import CsvDataLoader
from flowcean.environments.parquet import ParquetDataLoader


class UnsupportedFileTypeError(Exception):
    def __init__(self, suffix: str) -> None:
        super().__init__(f"file type `{suffix}` is not supported")


class UriDataLoader(OfflineEnvironment):
    """DataLoader for files specified by an URI."""

    uri: str
    data_loader: OfflineEnvironment | None = None

    def __init__(self, uri: str) -> None:
        """Initialize the UriDataLoader.

        Args:
            uri: Path to the URI file.
        """
        self.uri = uri

    @override
    def load(self) -> Self:
        path = _file_uri_to_path(self.uri)
        suffix = path.suffix
        if suffix == ".csv":
            self.data_loader = CsvDataLoader(path)
        elif suffix == ".parquet":
            self.data_loader = ParquetDataLoader(path)
        else:
            raise UnsupportedFileTypeError(suffix)
        self.data_loader.load()
        return self

    @override
    def get_data(self) -> pl.DataFrame:
        if self.data_loader is None:
            raise NotLoadedError
        return self.data_loader.get_data()


class InvalidUriSchemeError(Exception):
    def __init__(self, scheme: str) -> None:
        super().__init__(
            f"only file URIs can be converted to a path, but got `{scheme}`",
        )


def _file_uri_to_path(uri: str) -> Path:
    url = urlparse(uri)
    if url.scheme != "file":
        raise InvalidUriSchemeError(url.scheme)
    return Path(url.path)

==> flowcean-0.3.0.tar.gz: flowcean-0.3.0/src/flowcean/environments/uri.py <==
from pathlib import Path
from urllib.parse import urlparse

from flowcean.environments.csv import CsvDataLoader
from flowcean.environments.dataset import Dataset
from flowcean.environments.parquet import ParquetDataLoader


class UnsupportedFileTypeError(Exception):
    """Exception raised when a file type is not supported."""

    def __init__(self, suffix: str) -> None:
        """Initialize the UnsupportedFileTypeError.

        Args:
            suffix: File type suffix.
        """
        super().__init__(f"file type `{suffix}` is not supported")


class UriDataLoader(Dataset):
    """DataLoader for files specified by an URI."""

    def __init__(self, uri: str) -> None:
        """Initialize the UriDataLoader.

        Args:
            uri: Path to the URI file.
        """
        path = _file_uri_to_path(uri)
        suffix = path.suffix
        if suffix == ".csv":
            data_loader = CsvDataLoader(path)
        elif suffix == ".parquet":
            data_loader = ParquetDataLoader(path)
        else:
            raise UnsupportedFileTypeError(suffix)
        super().__init__(data_loader.data)


class InvalidUriSchemeError(Exception):
    """Exception raised when an URI scheme is invalid."""

    def __init__(self, scheme: str) -> None:
        """Initialize the InvalidUriSchemeError.

        Args:
            scheme: Invalid URI scheme.
        """
        super().__init__(
            f"only file URIs can be converted to a path, but got `{scheme}`",
        )


def _file_uri_to_path(uri: str) -> Path:
    url = urlparse(uri)
    if url.scheme != "file":
        raise InvalidUriSchemeError(url.scheme)
    return Path(url.path)
